mysql.exceptions.internal.No_Insert_ID_Error

Package mysql :: Package exceptions :: Module internal :: Class No_Insert_ID_Error |
[hide private]
[frames] | no frames]

# Class No_Insert_ID_Error

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              No_Insert_ID_Error

The last insert ID is not available when calling the mysql.connection.Connection.last_insert_id method.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`